==> struts-6.7.0-all.zip: struts-6.7.0/src/core/src/main/java/org/apache/struts2/interceptor/httpmethod/HttpMethodAware.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.interceptor.httpmethod;

/**
 * Action when implements this interface is notified about what method was used to perform request,
 * it works in connection with {@link HttpMethodInterceptor}
 *
 * Another function of this interface is to return result, which should be returned when action
 * was called with wrong http method
 *
 * @see HttpMethodInterceptor
 * @since 6.2.0
 */
public interface HttpMethodAware {

    /**
     * Notifies action about http method used to perform request
     *
     * @param httpMethod {@link javax.servlet.http.HttpServletRequest#getMethod()} translated to enum
     */
    void setMethod(HttpMethod httpMethod);

    /**
     * Action name to use when action was requested with wrong http method
     * can return null and then default result name will be used instead defined
     * in {@link HttpMethodInterceptor}
     *
     * @return result name or null
     */
    String getBadRequestResultName();

}

==> struts-7.0.0-all.zip: struts-7.0.0/src/core/src/main/java/org/apache/struts2/interceptor/httpmethod/HttpMethodAware.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.interceptor.httpmethod;

/**
 * Action when implements this interface is notified about what method was used to perform request,
 * it works in connection with {@link HttpMethodInterceptor}
 *
 * Another function of this interface is to return result, which should be returned when action
 * was called with wrong http method
 *
 * @see HttpMethodInterceptor
 * @since 6.2.0
 */
public interface HttpMethodAware {

    /**
     * Notifies action about http method used to perform request
     *
     * @param httpMethod {@link jakarta.servlet.http.HttpServletRequest#getMethod()} translated to enum
     */
    void setMethod(HttpMethod httpMethod);

    /**
     * Action name to use when action was requested with wrong http method
     * can return null and then default result name will be used instead defined
     * in {@link HttpMethodInterceptor}
     *
     * @return result name or null
     */
    String getBadRequestResultName();

}
